#ifndef __TRTL_CONFIG_ROM_H__
#define  __TRTL_CONFIG_ROM_H__

#define TRTL_CONFIG_ROM_SIGNATURE 0x5452544c

#define TRTL_MAX_CPU 8 /**< Maximum number of CPU core in a bitstream */
#define TRTL_MAX_MQ_CHAN 8 /**< Maximum number of (H|R)MQ slots in a
			      bitstream */

#define TRTL_CONFIG_ROM_MQ_ENTRIES_SHIFT 16
#define TRTL_CONFIG_ROM_MQ_ENTRIES_MASK 0x00FF0000
#define TRTL_CONFIG_ROM_MQ_PAYLOAD_SHIFT 8
#define TRTL_CONFIG_ROM_MQ_PAYLOAD_MASK 0x0000FF00
#define TRTL_CONFIG_ROM_MQ_HEADER_SHIFT 0
#define TRTL_CONFIG_ROM_MQ_HEADER_MASK 0x000000FF

#define TRTL_CONFIG_ROM_MQ_SIZE_ENTRIES(_size) (1 << ((_size & TRTL_CONFIG_ROM_MQ_ENTRIES_MASK) >> TRTL_CONFIG_ROM_MQ_ENTRIES_SHIFT))
#define TRTL_CONFIG_ROM_MQ_SIZE_PAYLOAD(_size) (1 << ((_size & TRTL_CONFIG_ROM_MQ_PAYLOAD_MASK) >> TRTL_CONFIG_ROM_MQ_PAYLOAD_SHIFT))
#define TRTL_CONFIG_ROM_MQ_SIZE_HEADER(_size) (1 << ((_size & TRTL_CONFIG_ROM_MQ_HEADER_MASK) >> TRTL_CONFIG_ROM_MQ_HEADER_SHIFT))

/**
 * The synthesis configuration for a single MQ.
 * Note that there is always an input and output channel for each declaration.
 */
struct trtl_config_rom_mq {
	uint32_t sizes;
	uint32_t endpoint_id;
};


/**
 * The synthesis configuration ROM descriptor shows useful configuration
 * options during synthesis.
 */
struct trtl_config_rom {
	uint32_t signature; /**< we expect to see a known value */
	uint32_t version; /**< Mock Turtle version */
	uint32_t pad1[1];
	uint32_t clock_freq;
	uint32_t flags;
	uint32_t app_id; /**< Application ID */
	uint32_t n_cpu; /**< number of CPU */
	uint32_t smem_size; /**< shared memory size */
	uint32_t mem_size[TRTL_MAX_CPU]; /**< memory size for each CPU */
	uint32_t n_hmq[TRTL_MAX_CPU]; /**< number of HMQ for each CPU */
	uint32_t n_rmq[TRTL_MAX_CPU]; /**< number of RMQ for each CPU */
	uint32_t pad2[96];
	struct trtl_config_rom_mq hmq[TRTL_MAX_CPU * TRTL_MAX_MQ_CHAN];
	struct trtl_config_rom_mq rmq[TRTL_MAX_CPU * TRTL_MAX_MQ_CHAN];
};

#endif
